@@ -4,14 +4,16 @@ package Class::Autouse::Parent;
 # a parent class. That is, a class who's primary job is to load a series
 # classes below it.
 
+use 5.006;
 use strict;
 use Class::Autouse ();
 
-use vars qw{$VERSION};
+our $VERSION;
 BEGIN {
-	$VERSION = '1.29';
+	$VERSION = '2.00';
 }
 
+# Anti-loop protection.
 # Maintain flags for "is the class in the process of loading"
 my %LOADING = ();
 
@@ -24,11 +26,11 @@ sub import {
 	return 1 if $LOADING{$parent};
 
 	# Autoload in our children
-	$LOADING{parent} = 1;
-	Class::Autouse->autouse_recursive( $parent );
-	delete $LOADING{parent};
+	$LOADING{$parent} = 1;
+	Class::Autouse->autouse_recursive($parent);
+	delete $LOADING{$parent};
 
-	1;
+	return 1;
 }
 
 1;
